<?php

/**
	Edge Theme Library

	The contents of this file are subject to the terms of the GNU General
	Public License Version 2.0. You may not use this file except in
	compliance with the license. Any of the license terms and conditions
	can be waived if you get permission from the copyright holder.

	Copyright (c) 2011 Bandit Media
	Jermaine Marée

		@package Theme
		@version 1.2
**/

//! Theme specific methods
class FeatherTheme extends FeatherBase {

	//@{ Theme details
	const
		THEME_Name='Edge',
		THEME_Version='1.2';
	//@}

	protected static
		//! Theme Language
		$theme_lang;

	/**
		Initialize Theme
			@public
	**/
	static function init() {
		// Content width
		global $content_width;
		if(!isset($content_width))
			$content_width=960;
		// Get theme language options
		self::$theme_lang=get_option('bandit_language');
		// Theme activation
		if('themes.php'==self::$vars['PAGENOW'] && isset($_GET['activated']))
			self::activation();

		// Theme admin
		if(is_admin()) {
			// Upgrade check
			self::upgrade_check();
			// Theme settings menu
			if(isset(self::$config['OPTION_TABS']))
				add_action('admin_menu',__CLASS__.'::admin_menu');
			// Admin init
			$pages=array('themes.php','options.php');
			if(in_array(self::$vars['PAGENOW'],$pages))
				add_action('admin_init',__CLASS__.'::admin_init');
		}

		// Theme non-admin
		if(!is_admin()) {
			// Load Helper
			self::load_theme_file('bandit-helper','lib');
			// Shortcodes
			if(self::load_theme_file('bandit-shortcode','lib')) {
				$shortcodes=array_diff(get_class_methods('BanditShortcode'),
					get_class_methods('FeatherBase'));
				foreach($shortcodes as $shortcode)
					add_shortcode($shortcode,'BanditShortcode::'.$shortcode);
			}
			// Theme filters
			add_action('after_setup_theme',__CLASS__.'::filters');
			// Theme javascript
			add_action('template_redirect',__CLASS__.'::javascript');
			// Add action to output to head
			add_action('wp_head',__CLASS__.'::wp_head');
			// Add action to output to footer
			add_action('wp_footer',__CLASS__.'::wp_footer');
		}
	}

	/**
		Theme Activation
			@private
	**/
	private static function activation() {
		// Set default language options
		if(!self::$theme_lang) {
			self::$theme_lang=array();
			// Load language
			$lang=FeatherConfig::theme('config-language','lang');
			// Loop through language settings
			foreach($lang as $key=>$value) {
				foreach($value['fields'] as $option=>$args)
					self::$theme_lang[$option]=$args['std'];
			}
			// Save language settings
			update_option('bandit_language',self::$theme_lang);
		}
	}

	/**
		Upgrade check
			@private
	**/
	private static function upgrade_check() {
		// Theme Version
		$version=self::get_theme_option('theme_version');
		// Set defaults
		if(!$version) {
			// Set theme framework options
			self::$option['auto_feed_links']='1';
			self::$option['post_thumbnails']='1';
			update_option('feather',self::$option);
			
			// Set default theme options
			self::$theme_option=array(
				'theme_version'=>FeatherTheme::THEME_Version,
				'comments_pages'=>'1'
			);
			update_option('bandit_edge',self::$theme_option);
		}
		// Upgrade if necessary
		if($version && ($version < self::THEME_Version)) {
			self::load_theme_file('bandit-upgrade','lib');
				BanditUpgrade::init($version);
		}
	}

	/**
		Get lang option
			@param $option string
			@public
	**/
	static function get_theme_lang($option=NULL) {
		if(isset(self::$theme_lang[$option]))
			$result=self::$theme_lang[$option];
		else
			$result=FALSE;
		return $result;
	}

	/**
		Javascript
			@public
	**/
	static function javascript() {
		// Default scripts
		$scripts=array('jquery','jquery-ui-core','jquery-ui-tabs');

		// Register and load carouFredSel if widget is active
		if(is_active_widget('','','bandit_edgefeaturedposts') ||
			(is_front_page() && self::get_theme_option('theme_featured_display'))) {
			// Register carouFredSel
			wp_enqueue_script('carouFredSel',get_bloginfo('template_url').
				'/js/jquery.carouFredSel-3.2.1-min.js',array('jquery'));
		}

		// Register edge.js
		wp_enqueue_script('bandit-theme',get_bloginfo('template_url').
			'/js/jquery.theme.js',$scripts,'1.0');
	}

	/**
		Theme styles
			@public
	**/
	static function styles() {
		// Styles directory
		$styles_dir=TEMPLATEPATH.'/styles';
		// Default style
		$default=array('0'=>'Default');
		// Empty array
		$styles=array();
		if(is_dir($styles_dir) && $handle=opendir($styles_dir)) {
			while(false !== ($file=readdir($handle))) {
				if($file!="." && $file!=".." && is_file($styles_dir.'/'.$file)) {
					$tmp = new \SplFileObject($styles_dir.'/'.$file);
					$tmp->seek(1);
					$name=substr(esc_html($tmp->current()),7);
					$styles[$file]=$name;
				}
			}
			closedir($handle);
			// Combine arrays
			if($styles) {
				asort($styles);
				$styles=$default+$styles;
			}
		}
		return $styles?$styles:FALSE;
	}

	/**
		Theme filters
			@public
	**/
	static function filters() {
		if(self::get_config('FILTERS'))
			foreach(self::$config['FILTERS'] as $tag=>$function) {
				if(!isset($function['priority']))
					$function['priority']=10;
				if(!isset($function['args']))
				 $function['args']=1;
				add_filter($tag,__CLASS__.'::'.$function['name'],
					$function['priority'],$function['args']);
			}
		// Feed link filter
		if(self::get_theme_option('feed_url'))
			add_filter('feed_link',__CLASS__.'::filter_feedlink',10,2);
	}

	/**
		Theme WP Head
			@public
	**/
	static function wp_head() {
		// Analytics script
		if(self::get_theme_option('analytics_script'))
			if('header'===self::get_theme_option('analytics_location'))
				echo self::$theme_option['analytics_script']."\n";
	}

	/**
		Theme WP Footer
			@public
	**/
	static function wp_footer() {
		// Analytics script
		if(self::get_theme_option('analytics_script'))
			if('footer'===self::get_theme_option('analytics_location'))
				echo self::$theme_option['analytics_script']."\n";
	}

	/**
		Theme feed link filter
			@public
	**/
	static function filter_feedlink($output,$feed) {
		$feed_url=self::get_theme_option('feed_url');
		$feed_array = array('rss'=>$feed_url, 'rss2'=>$feed_url,
			'atom'=>$feed_url, 'rdf'=>$feed_url, 'comments_rss2'=>'');
		$feed_array[$feed]=$feed_url;
		return $feed_array[$feed];
	}

	/**
		Sets theme body class
			@public
	**/
	static function filter_body_class($classes) {
		if(is_active_widget('','','bandit_edgefeaturedposts'))
			$classes[]='featured';
		if(is_front_page() && self::get_theme_option('theme_featured_display'))
			$classes[]='featured-home';
		return $classes;
	}

	/**
		Theme admin menu
			@public
	**/
	static function admin_menu() {
		// Add page to the Appearance menu
		add_theme_page('Theme Options','Theme Options','edit_theme_options',
			'feather',__CLASS__.'::admin_options_page');
	}

	/**
		Theme options page
			@public
	**/
	static function admin_options_page() {
		$file='theme-options-page';
		if(!self::load_theme_file($file,'tmpl')) {
			$message=sprintf(self::TEXT_File,$file.'.php');
			echo '<div class="wrap"><div id="message" class="error"><p>'.
				'Feather : '.$message.'</p></div></div>';
		}
	}

	/**
		Theme admin init
			@public
	**/
	static function admin_init() {
		// Theme options stylesheet
		add_action('admin_print_styles-appearance_page_feather',
			__CLASS__.'::admin_stylesheets');
		// Theme options javacript
		add_action('admin_print_scripts-appearance_page_feather',
			__CLASS__.'::admin_javascript');
		// Register theme settings
		register_setting('bandit_edge-settings','bandit_edge',
			__CLASS__.'::admin_validate_settings');
		// Register language settings
		register_setting('bandit_language-settings','bandit_language',
			__CLASS__.'::admin_validate_settings');
		// Initialize theme settings
		self::admin_settings_init();
	}

	/**
		Theme settings init
			@private
	**/
	private static function admin_settings_init() {
		$tab=FeatherAdmin::get_current_options_page_tab('theme');
		// Theme Settings (non-language)
		if('language'!==$tab) {
			// Theme settings
			self::$theme_setting=FeatherConfig::theme('config-settings','setting');
			// Process settings
			FeatherAdmin::process_settings(self::$theme_setting,'bandit_edge');
		}
		// Language Settings
		if('language'==$tab) {
			// Language settings
			self::$theme_setting=FeatherConfig::theme('config-language','lang');
			// Process settings
			FeatherAdmin::process_settings(self::$theme_setting,'bandit_language',
				__CLASS__.'::get_theme_lang');
		}
	}

	/**
		Theme admin stylesheets
			@public
	**/
	static function admin_stylesheets() {
		// Framework stylesheet
		wp_enqueue_style('feather-admin-css',
			FEATHER_URL.'assets/css/feather-admin.css',FALSE,20110923);
		// Peak stylesheet
		wp_enqueue_style('theme-admin-css',
			FEATHER_URL_THEME.'assets/css/theme-admin.css',FALSE,20110923);
		// Load tab specific styles
		if('general'==FeatherAdmin::get_current_options_page_tab('theme'))
			wp_enqueue_style('thickbox');
	}

	/**
		Theme javascripts
			@public
	**/
	static function admin_javascript() {
		// Register scripts
		wp_register_script('theme-admin-general',FEATHER_URL_THEME.'assets/js/theme-admin-general.js',
			array('media-upload','thickbox','jquery'),20110921);
		// Load tab specific scripts
		if('general'==FeatherAdmin::get_current_options_page_tab('theme'))
			wp_enqueue_script('theme-admin-general');
	}

	/**
		Theme validate admin settings
			@public
	**/
	static function admin_validate_settings($input) {
		// Get tab
		$tab=$input['tab'];
		// Unset bandit_tab option
		unset($input['tab']);

		// Theme Tab
		if('theme'==$tab) {
			// Get current options
			$valid=self::$theme_option;
			// Validate options
			$valid['theme_style']=wp_filter_nohtml_kses($input['theme_style']);
			// Define checkbox options
			$checkboxes='theme_featured_display|theme_featured_display_content|'.
				'theme_post_thumb_blog';
			// Validate options
			foreach(explode('|',$checkboxes) as $option) 
				$valid[$option]=isset($input[$option])?'1':'0';
			$valid['theme_featured_catid']=wp_filter_nohtml_kses($input['theme_featured_catid']);
			$valid['theme_featured_num']=in_array($input['theme_featured_num'],range(5,15))?$input['theme_featured_num']:'5';
		}

		// General Tab
		if('general'==$tab) {
			// Get current options
			$valid=self::$theme_option;
			// Define checkbox options
			$checkboxes='disable_tagline|custom_styles|'.
				'comments_pages|comments_posts|analytics_location';
			// Validate options
			foreach(explode('|',$checkboxes) as $option) 
				$valid[$option]=isset($input[$option])?'1':'0';
			$valid['custom_logo']=wp_filter_nohtml_kses($input['custom_logo']);
			$valid['feed_url']=wp_filter_nohtml_kses($input['feed_url']);
			$valid['social_facebook']=wp_filter_nohtml_kses($input['social_facebook']);
			$valid['social_flickr']=wp_filter_nohtml_kses($input['social_flickr']);
			$valid['social_twitter']=wp_filter_nohtml_kses($input['social_twitter']);
			$valid['analytics_location']=('header'===$input['analytics_location']?'header':'footer');
			$valid['analytics_script']=$input['analytics_script'];
		}

		// Language Tab
		if('language'==$tab) {
			// Save language settings
			if(!isset($input['reset'])) {
				// Get current settings
				$valid=self::$theme_lang;
				// Language settings
				self::$theme_setting=FeatherConfig::theme('config-language','lang');
				// Loop through language settings
				foreach(self::$theme_setting as $key=>$value) {
					// Loop through fields
					foreach($value['fields'] as $option=>$args)
						$valid[$option]=wp_filter_kses($input[$option]);
				}
			}
			// Reset language settings
			if(isset($input['reset'])) {
				// Unset reset option
				unset($input['reset']);
				// Set blank option
				update_option('bandit_language',array());
				// Language settings
				self::$theme_setting=FeatherConfig::theme('config-language','lang');
				// Loop through language settings
				foreach(self::$theme_setting as $key=>$value) {
					// Reset fields to defaults
					foreach($value['fields'] as $option=>$args)
						$valid[$option]=$args['std'];
				}
			}
		}
		// Settings saved notice
		add_settings_error('feather_setting_notices',
			esc_attr('settings_updated'),__('Settings saved.'),'updated');
		// Return validated options
		return $valid;
	}

	/**
		Featured Category Field
			@public
	**/
	static function print_field_featcat($args) {
		// Arguments for category dropdown
		$cat_args=array(
			'hide_empty'=>0,
			'echo'=>0,
			'name'=>'bandit_edge[theme_featured_catid]',
			'orderby'=>'name',
			'selected'=>self::get_theme_option('theme_featured_catid')
		);
		// Create dropdown
		$output=wp_dropdown_categories($cat_args);
		echo $output;
	}

}
